gnugo-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[gnugo-devel] empty_corner_value on smaller boards


From: Arend Bayer
Subject: [gnugo-devel] empty_corner_value on smaller boards
Date: Tue, 20 Nov 2001 02:08:56 +0100 (CET)

- empty_corner_value adjusted to board size

The fixed empty_corner_value = 25 seems to contradict the fact that J moves
(which should be more important than an empty corner) are currently valued
with 27 * boardsize / 19. I am not sure whether this treatment of the J
values actually makes sense, but they should definitely be weighed higher
than an empty corner.

-Arend

Index: engine/fuseki.c
===================================================================
RCS file: /cvsroot/gnugo/gnugo/engine/fuseki.c,v
retrieving revision 1.9
diff -u -r1.9 fuseki.c
--- engine/fuseki.c     2001/10/09 19:20:58     1.9
+++ engine/fuseki.c     2001/11/20 01:07:37
@@ -46,7 +46,9 @@
 #define LOWER_LEFT  2
 #define LOWER_RIGHT 3
 
 /* This value must be lower than the value for an ongoing joseki. */
 #define EMPTY_CORNER_VALUE 25
 
 /* check if region from i1, j1 to i2, j2 is open */
@@ -277,7 +279,7 @@
   int i = -1;
   int j = -1;
   int width;  /* Side of the open region required in the corner. */
-  int empty_corner_value = EMPTY_CORNER_VALUE;
+  int empty_corner_value = EMPTY_CORNER_VALUE * board_size/19;
 
   /* Return immediately if --disable_fuseki option used. */
   if (disable_fuseki)
@@ -46,7 +46,9 @@
 #define LOWER_RIGHT 3
 
-/* This value must be lower than the value for an ongoing joseki. */
+/* This value must be lower than the value for an ongoing joseki. 
+ * (Gets multiplied with board_size / 19.) 
+ */
 #define EMPTY_CORNER_VALUE 25
 






reply via email to

[Prev in Thread] Current Thread [Next in Thread]